Welcome to mirror list, hosted at ThFree Co, Russian Federation.

git.blender.org/blender.git - Unnamed repository; edit this file 'description' to name the repository.
summaryrefslogtreecommitdiff
diff options
context:
space:
mode:
Diffstat (limited to 'source/blender/makesdna/DNA_windowmanager_types.h')
-rw-r--r--source/blender/makesdna/DNA_windowmanager_types.h6
1 files changed, 4 insertions, 2 deletions
diff --git a/source/blender/makesdna/DNA_windowmanager_types.h b/source/blender/makesdna/DNA_windowmanager_types.h
index c6ad1470561..0ef9e9b134a 100644
--- a/source/blender/makesdna/DNA_windowmanager_types.h
+++ b/source/blender/makesdna/DNA_windowmanager_types.h
@@ -186,8 +186,10 @@ typedef struct wmWindow {
void *ghostwin; /* don't want to include ghost.h stuff */
void *gwnctx; /* don't want to include gawin stuff */
- struct Scene *scene; /* The scene displayed in this window. */
- struct Scene *new_scene; /* temporary when switching */
+ struct wmWindow *parent; /* Parent window */
+
+ struct Scene *scene; /* The scene displayed in this window. */
+ struct Scene *new_scene; /* temporary when switching */
struct WorkSpaceInstanceHook *workspace_hook;